/*----------------------------------------------------------------------------
 *
 *  ecurses.h - header of enhanced curses
 *
 *  Location: /usr/local/include/ecurses.h
 *
 *----------------------------------------------------------------------------
 */

/*----------------------------------------------------------------------------
 * DIESES LISTING IST LEDIGLICH EIN AUSSCHNITT, IN DEM DIE NTIGEN
 * 256 FUNKTIONSTASTEN DEFINIERT SIND
 *----------------------------------------------------------------------------
 */

#include <stdio.h>

#ifndef TRUE
# define TRUE		(1)
# define FALSE		(0)
#endif

#define OK		(0)		/* return values of most ecurses    */
#define ERR		(-1)		/* functions			    */

/*----------------------------------------------------------------------------
 *	FUNCTION KEYS  Codes begin at 0x100, end at 0x1ff (256 keys)
 *	The following function keys are return values of getch() :
 *----------------------------------------------------------------------------
 */

#define KEY_ERR		(-2)		/* unknown key			    */

#define KEY_DOWN	0x100		/* Down arrow key		    */
#define KEY_UP		0x101		/* Up arrow key			    */
#define KEY_LEFT	0x102		/* Left arrow key		    */
#define KEY_RIGHT	0x103		/* Right arrow key		    */
#define KEY_SDOWN	0x104		/* Shifted down arrow key	    */
#define KEY_SUP		0x105		/* Shifted up arrow key		    */
#define KEY_SLEFT	0x106		/* Shifted left arrow key	    */
#define KEY_SRIGHT	0x107		/* Shifted left arrow key	    */
#define KEY_HOME	0x108		/* Home key			    */
#define KEY_SHOME	0x109		/* Shifted home key		    */
#define KEY_DL		0x10A		/* Delete line key		    */
#define KEY_IL		0x10B		/* Insert line key		    */
#define KEY_DW		0x10C		/* Delete word key		    */
#define KEY_IW		0x10D		/* Insert word key		    */
#define KEY_DC		0x10E		/* Delete character key		    */
#define KEY_IC		0x10F		/* Ins char/toggle ins mode key	    */
#define KEY_CLEAR	0x110		/* Clear screen or erase key	    */
#define KEY_SCLEAR	0x111		/* Shifted clear screen/erase key   */
#define KEY_EOS		0x112		/* Clear-to-end-of-screen key	    */
#define KEY_EOL		0x113		/* Clear-to-end-of-line key	    */
#define KEY_NPAGE	0x114		/* Next-page key		    */
#define KEY_PPAGE	0x115		/* Previous-page key		    */
#define KEY_PRINT	0x116		/* Print or copy		    */
#define KEY_BTAB	0x117		/* Back tab key			    */
#define KEY_END		0x118		/* End key			    */
#define KEY_FIND	0x119		/* Find key (vt200)		    */
#define KEY_SELECT	0x11A		/* Select key (vt200)		    */
#define KEY_MODE	0x11B		/* Mode key (97801)		    */
#define KEY_SMODE	0x11C		/* Shifted Mode key (97801)	    */
#define KEY_HELP	0x11D		/* Help key (97801)		    */
#define KEY_START	0x11E		/* Start key (97801)		    */
#define KEY_0x11F	0x11F		/* UNUSED !			    */

#define KEY_PAD_0	0x120		/* VT100 keypad 0 key		    */
#define KEY_PAD_1	0x121		/* VT100 keypad 1 key		    */
#define KEY_PAD_2	0x122		/* VT100 keypad 2 key		    */
#define KEY_PAD_3	0x123		/* VT100 keypad 3 key		    */
#define KEY_PAD_4	0x124		/* VT100 keypad 4 key		    */
#define KEY_PAD_5	0x125		/* VT100 keypad 5 key		    */
#define KEY_PAD_6	0x126		/* VT100 keypad 6 key		    */
#define KEY_PAD_7	0x127		/* VT100 keypad 7 key		    */
#define KEY_PAD_8	0x128		/* VT100 keypad 8 key		    */
#define KEY_PAD_9	0x129		/* VT100 keypad 9 key		    */
#define KEY_PAD_MINUS	0x12A		/* VT100 keypad - (minus) key	    */
#define KEY_PAD_COMMA	0x12B		/* VT100 keypad , (comma) key	    */
#define KEY_PAD_PERIOD	0x12C		/* VT100 keypad . (period) key	    */
#define KEY_PAD_ENTER	0x12D		/* VT100 keypad ENTER key	    */
#define KEY_0x12E	0x12E		/* UNUSED !			    */
#define KEY_0x12F	0x12F		/* UNUSED !			    */

#define KEY_PAD_PF0	0x130		/* 97801 pseudo PF0		    */
#define KEY_PAD_PF1	0x131		/* VT100 or 97801 pseudo PF1 key    */
#define KEY_PAD_PF2	0x132		/* VT100 or 97801 pseudo PF2 key    */
#define KEY_PAD_PF3	0x133		/* VT100 or 97801 pseudo PF3 key    */
#define KEY_PAD_PF4	0x134		/* VT100 or 97801 pseudo PF4 key    */
#define KEY_SPAD_PF0	0x135		/* Shifted PF0 key (which has it?)  */
#define KEY_SPAD_PF1	0x136		/* Shifted PF1 key (Facit Twist)    */
#define KEY_SPAD_PF2	0x137		/* Shifted PF2 key (Facit Twist)    */
#define KEY_SPAD_PF3	0x138		/* Shifted PF3 key (Facit Twist)    */
#define KEY_SPAD_PF4	0x139		/* Shifted PF4 key (Facit Twist)    */
#define KEY_WORD_LEFT	0x13A		/* Word-Left key (97801)	    */
#define KEY_WORD_RIGHT	0x13B		/* Word-Right key (97801)	    */
#define KEY_0x13C	0x13C		/* UNUSED !			    */
#define KEY_L_BUTTON	0x13D		/* X-Driver: left mouse button	    */
#define KEY_M_BUTTON	0x13E		/* X-Driver: middle mouse button    */
#define KEY_R_BUTTON	0x13F		/* X-Driver: right mouse button	    */

#define KEY_F0		0x140		/* Function key F0		    */
#define KEY_F(n)	(KEY_F0+(n))	/* Additional 31 function keys      */

#define KEY_SF0		0x160		/* Function key SHIFT + F0	    */
#define KEY_SF(n)	(KEY_SF0+(n))	/* Additional 31 shifted fkeys      */

#define KEY_CF0		0x180		/* Function key CTRL + F0	    */
#define KEY_CF(n)	(KEY_CF0+(n))	/* Additional 31 CTRL-fkeys	    */

#define KEY_AF0		0x1A0		/* Function key ALT + F0	    */
#define KEY_AF(n)	(KEY_AF0+(n))	/* Additional 31 ALT-fkeys	    */

#define KEY_SCF0	0x1C0		/* Function key SHIFT-CTRL + F0	    */
#define KEY_SCF(n)	(KEY_SAF0+(n))	/* Additional 31 SHIFT-CTRL-fkeys    */

#define KEY_SAF0	0x1E0		/* Function key SHIFT-ALT + F0	    */
#define KEY_SAF(n)	(KEY_SCF0+(n))	/* Additional 31 SHIFT-ALT-fkeys   */

/* End of local/ecurses.h */
